/*
 * Refer to USBLooper.cpp. This software is released under
 * the LGPL (Lesser General Public License). The license:
 * 
 * http://www.gnu.org/copyleft/lesser.html
 *
 * (Notice the application signature for USBLooper contains 'LGPL'.)
 *
 * Copyright (c) 1999 Thomas S. Winzig. All rights reserved.
 *
 * -----------------------------------------------------------------------
 */

#ifndef _USBLOOPER_H_
#define _USBLOOPER_H_

#include <Application.h>
#include <Message.h>
#include "usb/USBKit.h"
#include "USBLooperUtil.h"

/* E.g. My camera is at: /dev/bus/usb/0/1/1 

[Device]
Class .................. 0
Subclass ............... 0
Protocol ............... 0
Vendor ID .............. 0x040a
Product ID ............. 0x0111
Version ................ 0x0100
Manufacturer String .... "Eastman Kodak Company"
Product String ......... "KODAK DC265 ZOOM DIGITAL CA"
Serial Number .......... ""
  [Configuration 0]
    [Interface 0]
    Class .............. 0
    Subclass ........... 0
    Protocol ........... 0
      [Endpoint 0]
      MaxPacketSize .... 64
      Interval ......... 0
      Type ............. Bulk
      Direction ........ Input
      [Endpoint 1]
      MaxPacketSize .... 64
      Interval ......... 0
      Type ............. Bulk
      Direction ........ Output     

*/

bool NotifyApp(void *remote_app, void *message)
{
	((BMessenger *)remote_app)->SendMessage((BMessage *) message);
	return false;
}

class USBLooperRoster : public USBRoster
{
	public:
							USBLooperRoster();
							~USBLooperRoster();
		virtual status_t 	DeviceAdded(USBDevice *dev);
		virtual void 		DeviceRemoved(USBDevice *dev);
		virtual void		MessageReceived(BMessage *message);
	
	private:
		BMessage			*usb_devices;
		BMessage			*usb_devices_paths;
		BList				*apps;
};

class USBLooper : public BApplication
{
	public:
							USBLooper();
		virtual void		MessageReceived(BMessage *message);
	
	private:
		USBLooperRoster		*roster;
};


#endif
